@@ -1,4 +1,4 @@
-### Copyright (C) 2002-2003 Stephen Kennedy <stevek@gnome.org>
+### Copyright (C) 2002-2006 Stephen Kennedy <stevek@gnome.org>
 
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -18,24 +18,26 @@ import os
 
 _locale_dir = ( #LOCALEDIR#
 )
-_doc_dir = ( #DOCDIR#
+_help_dir = ( #HELPDIR#
 )
 _share_dir = ( #SHAREDIR#
 )
 
-import sys
-appdir = os.path.dirname(sys.argv[0])
+appdir = os.path.dirname(__file__)
 
 if not _locale_dir: _locale_dir = os.path.join(appdir,"po")
-if not _doc_dir:    _doc_dir    = os.path.join(appdir,"manual")
+if not _help_dir:    _help_dir  = os.path.join(appdir,"help")
 if not _share_dir:  _share_dir  = appdir
 
 def locale_dir(*args): # i18n files
     return os.path.join(_locale_dir, *args)
 
-def doc_dir(*args): # manual
-    return os.path.join(_doc_dir, *args)
+def help_dir(*args): # help
+    return os.path.join(_help_dir, *args)
 
-def share_dir(*args): # glade + pixmaps
-    return os.path.join(_share_dir, *args)
+def ui_dir(*args):
+    return os.path.join(_share_dir, "glade2", *args)
+
+def icon_dir(*args):
+    return os.path.join(_share_dir, "glade2", "pixmaps", *args)
 
