@@ -15,8 +15,8 @@
 ### Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import os
+import gobject
 import gtk
-import misc
 import gnomeglade
 import paths
 
@@ -27,17 +27,19 @@ from vc._vc import STATE_IGNORED, STATE_NONE, STATE_NORMAL, STATE_NOCHANGE, \
     STATE_MODIFIED, STATE_CONFLICT, STATE_REMOVED, \
     STATE_MISSING, STATE_MAX
 
-load = lambda x,s=14: gnomeglade.load_pixbuf( paths.share_dir("glade2/pixmaps",x), s)
+load = lambda x,s=14: gnomeglade.load_pixbuf(paths.icon_dir(x), s)
 pixbuf_folder = load("tree-folder-normal.png", 20)
 pixbuf_folder_new = load("tree-folder-new.png", 20)
 pixbuf_folder_changed = load("tree-folder-changed.png", 20)
+pixbuf_folder_missing = load("tree-folder-missing.png", 20)
 pixbuf_file = load("tree-file-normal.png")
 pixbuf_file_new = load("tree-file-new.png")
 pixbuf_file_changed = load("tree-file-changed.png")
+pixbuf_file_missing = load("tree-file-missing.png")
 
 class DiffTreeStore(gtk.TreeStore):
-    def __init__(self, ntree = 3):
-        types = [type("")] * COL_END * ntree
+    def __init__(self, ntree = 3, num_col = COL_END):
+        types = [type("")] * num_col * ntree
         types[COL_ICON*ntree:COL_ICON*ntree+ntree] = [type(pixbuf_file)] * ntree
         gtk.TreeStore.__init__(self, *types)
         self.ntree = ntree
@@ -69,7 +71,7 @@ class DiffTreeStore(gtk.TreeStore):
             (pixbuf_file_changed, pixbuf_folder_changed), # MODIFIED
             (pixbuf_file_changed, pixbuf_folder_changed), # CONFLICT
             (pixbuf_file_changed, pixbuf_folder_changed), # REMOVED
-            (None, None) # MISSING
+            (pixbuf_file_missing, pixbuf_folder_missing) # MISSING
         ]
         assert len(self.pixstyle) == STATE_MAX
 
@@ -84,7 +86,7 @@ class DiffTreeStore(gtk.TreeStore):
         for i in range(self.ntree):
             self.set_value(child, self.column_index(COL_STATE,i), STATE_EMPTY)
             self.set_value(child, self.column_index(COL_PATH,i), self.pixstyle[STATE_EMPTY])
-            self.set_value(child, self.column_index(COL_TEXT,i), self.textstyle[STATE_EMPTY] % misc.escape(text) )
+            self.set_value(child, self.column_index(COL_TEXT, i), self.textstyle[STATE_EMPTY] % gobject.markup_escape_text(text))
         return child
 
     def add_error(self, parent, msg, pane):
@@ -92,28 +94,28 @@ class DiffTreeStore(gtk.TreeStore):
         for i in range(self.ntree):
             self.set_value(err, self.column_index(COL_STATE,i), STATE_ERROR)
         self.set_value(err, self.column_index(COL_ICON, pane), self.pixstyle[STATE_ERROR][0] )
-        self.set_value(err, self.column_index(COL_TEXT, pane), self.textstyle[STATE_ERROR] % misc.escape(msg) )
+        self.set_value(err, self.column_index(COL_TEXT, pane), self.textstyle[STATE_ERROR] % gobject.markup_escape_text(msg))
 
-    def value_paths(self, iter):
-        return [ self.value_path(iter, i) for i in range(self.ntree) ]
-    def value_path(self, iter, pane):
-        return self.get_value(iter, self.column_index(COL_PATH, pane) )
+    def value_paths(self, it):
+        return [self.value_path(it, i) for i in range(self.ntree)]
+    def value_path(self, it, pane):
+        return self.get_value(it, self.column_index(COL_PATH, pane))
     def column_index(self, col, pane):
         return self.ntree * col + pane
 
-    def set_state(self, iter, pane, state, isdir=0):
-        fullname = self.get_value(iter, self.column_index(COL_PATH,pane))
-        name = misc.escape( os.path.basename(fullname) )
+    def set_state(self, it, pane, state, isdir=0):
+        fullname = self.get_value(it, self.column_index(COL_PATH,pane))
+        name = gobject.markup_escape_text(os.path.basename(fullname))
         STATE = self.column_index(COL_STATE, pane)
         TEXT  = self.column_index(COL_TEXT,  pane)
         ICON  = self.column_index(COL_ICON,  pane)
-        self.set_value(iter, STATE, state)
-        self.set_value(iter, TEXT,  self.textstyle[state] % name)
-        self.set_value(iter, ICON,  self.pixstyle[state][isdir])
+        self.set_value(it, STATE, state)
+        self.set_value(it, TEXT,  self.textstyle[state] % name)
+        self.set_value(it, ICON,  self.pixstyle[state][isdir])
 
-    def get_state(self, iter, pane):
+    def get_state(self, it, pane):
         STATE = self.column_index(COL_STATE, pane)
-        return self.get_value(iter, STATE)
+        return self.get_value(it, STATE)
 
     def inorder_search_down(self, it):
         while it:
